@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # encoding: utf-8
 
-from .consts import LOGS, DB_CREDENTIALS
+from .consts import LOGS, DB_CREDENTIALS, REDIS_DB
 import records
 
 
