@@ -53,18 +53,24 @@ class IzyTV(object):
                                 LOGS.logger.info(result)
                                 data["info"] = "Activation reussie"
                                 data["partner_ref"] = response["response"]["MvolaTransactionID"]
-                                REDIS_DB.hmset(transId, data)
+                                record = REDIS_DB.hmset(transId, data)
+                                while not record:
+                                    record = REDIS_DB.hmset(transId, data)
                                 # Mettre à jour la base postgres
                             else:
                                 LOGS.logger.info(result)
                                 # On réactivate plus tard
                         elif response["status"] == 2:  # Processus en cours
                             data["status"] = "En attente de paiement"
-                            REDIS_DB.hmset(transId, data)
+                            record = REDIS_DB.hmset(transId, data)
+                            while not record:
+                                record = REDIS_DB.hmset(transId, data)
                         elif response["status"] == 3:  # Transaction annulée coté telma
                             data["status"] = "Transaction annulée"
                             data["info"] = "Activation annulée"
-                            REDIS_DB.hmset(transId, data)
+                            record = REDIS_DB.hmset(transId, data)
+                            while not record:
+                                record = REDIS_DB.hmset(transId, data)
                         elif response["status"] == 1:  # en attente
                             date = datetime.datetime.strptime(
                                 data["TransactionDate"],
@@ -74,7 +80,9 @@ class IzyTV(object):
                             if ((now - date).total_seconds() / 60.0) >= trans_timeout:
                                 data["status"] = "Transaction annulée"
                                 data["info"] = "Activation annulée"
-                                REDIS_DB.hmset(transId, data)
+                                record = REDIS_DB.hmset(transId, data)
+                                while not record:
+                                    record = REDIS_DB.hmset(transId, data)
                     else:
                         LOGS.logger.info(response)
                 elif data["operator"] == "orange-izytv":
@@ -122,7 +130,9 @@ class IzyTV(object):
                             data["status"] = "Transaction annulée"
                             data["info"] = "Activation annulée"
                     # update Redis
-                    REDIS_DB.hmset(transId, data)
+                    record = REDIS_DB.hmset(transId, data)
+                    while not record:
+                        record = REDIS_DB.hmset(transId, data)
                 elif data["operator"] == "airtel-izytv":
                     self.airtel_izytv(transId, data)
                 else:
@@ -175,7 +185,9 @@ class IzyTV(object):
             data["status"] = "Transaction annulée"
             data["info"] = "Activation annulée"
         # update Redis
-        REDIS_DB.hmset(transId, data)
+        record = REDIS_DB.hmset(transId, data)
+        while not record:
+            record = REDIS_DB.hmset(transId, data)
 
     def sort_data(self):
         data = []
