@@ -204,14 +204,47 @@ class OrangeMoney(object):
                         response,
                     )
                 )
-                REDIS_DB.hmset(
-                    "request:payment:{}".format(data["pay_token"]),
-                    {
-                        "partner_ref": jresponse['txnid'],
-                    },
-                )
+                self.updateRefPartner({
+                    "redis_key": "request:payment:{}".format(data["pay_token"]),
+                    "tnxid": jresponse["txnid"],
+                })
             return response
 
+    def updateRefPartner(self, transaction):
+        """
+        For some unknown reasons, we can update directly a key-value dictionnary pair
+        from the shell in Redis, but when it goes through our service, it doesn't
+        work. So we need to pass again ALL the dictionnary inside Redis to
+        overwrite the entry...
+        """
+        redis_key = transaction.get("redis_key")
+        old_entry = REDIS_DB.hgetall(redis_key)
+        new_entry = {
+            "TransactionDate": old_entry[b"TransactionDate"],
+            "amount": old_entry[b"amount"],
+            "order_id": old_entry[b"order_id"],
+            "label": old_entry[b"label"],
+            "device_id": old_entry[b"device_id"],
+            "other": old_entry[b"other"],
+            "client_refnum": old_entry[b"client_refnum"],
+            "offre_refnum": old_entry[b"offre_refnum"],
+            "caller_num": old_entry[b"caller_num"],
+            "status": old_entry[b"status"],
+            "operator": old_entry[b"operator"],
+            "service_type": old_entry[b"service_type"],
+            "info": old_entry[b"info"],
+            "partner_ref": transaction.get('tnxid'),
+        }
+        REDIS_DB.delete(redis_key)
+        REDIS_DB.hmset(
+            redis_key,
+            new_entry,
+        )
+        current_record = REDIS_DB.hgetall(redis_key)
+        LOGS.logger.info(
+            "[OrangeMoney] {}\n".format(current_record)
+        )
+
 # status requests functions
 
     def checkTransactionStatusRedis(self, order_id):
